@@ -1,9 +1,28 @@
 (function () {
     "use strict";
 
+    const STORAGE_KEY_WAS_ENABLED_FOR_HOST = "__darkreader__wasEnabledForHost";
+    function wasEnabledForHost() {
+        try {
+            const value = sessionStorage.getItem(
+                STORAGE_KEY_WAS_ENABLED_FOR_HOST
+            );
+            if (value === "true") {
+                return true;
+            }
+            if (value === "false") {
+                return false;
+            }
+            return null;
+        } catch (err) {
+            return null;
+        }
+    }
+
     if (
         document.documentElement instanceof HTMLHtmlElement &&
         matchMedia("(prefers-color-scheme: dark)").matches &&
+        wasEnabledForHost() !== false &&
         !document.querySelector(".darkreader--fallback") &&
         !document.querySelector(".darkreader")
     ) {
